/*
Elektrobox - sklada se z kvadru a rozsireneho podstavce.

standX x standYTop je rozmer podstavce nahore, u kvadru.
standXBottom x standY je rozmer podstavce dole, u zakladny.

Podivny rozsireny podstavec je provedeny jako Polyhedron
*/
standX = 4.2;
standXBottom = 2.8;
standY = 4.0;
standYTop = 3.0;
standLowH = 1.2;

module podstavecDole() {

standYdiff = (standY - standYTop) / 2;
standXdiff = (standX - standXBottom) / 2;

cubepoints = [
    [standXdiff, 0, 0],              // 0
    [standX - standXdiff, 0, 0],         // 1
    [standX - standXdiff, standY, 0],    // 2
    [standXdiff, standY, 0],         // 3
    
    [0, standYdiff, standLowH],                    // 4
    [standX, standYdiff, standLowH],               // 5
    [standX, standY - standYdiff, standLowH],      // 6
    [0, standY - standYdiff, standLowH],           // 7
];
cubefaces = [
    [ 0, 1, 2, 3],
    [ 7, 6, 5, 4],
    [ 0, 3, 7, 4],
    [ 5, 6, 2, 1],
    [ 4, 5, 1, 0],
    [ 6, 7, 3, 2]
];

translate([- standX / 2, - standY / 2, 0])  polyhedron(
    cubepoints,
    cubefaces,
    convexity = 10
);
}

module podstavec() {
    union() {
        podstavecDole();
        translate([- standX / 2, - standYTop / 2, standLowH]) cube([standX, standYTop, 4]);
    }
}

// ---------------------------------------------------------------------------------
stozar_prumer = 2;
dutina_prumer = 1.3;

/*
Teio stozaru. 
- Valec, 
- nahore krouzek 
- dole podstavec
- to cele proderavele dirou
*/
module stozar() {
    rotate([90, 0, 0]) 
    difference() {
        union() {
            translate([0, 0, 48]) cylinder(h = 1, r = (2.7 / 2), $fn=50);
            cylinder(h=50, r= stozar_prumer / 2, $fn=50);
//            translate([0, 0, 5]) podstavec();
        }
        cylinder(h=50, r=dutina_prumer / 2, $fn=50);
    }
}

/*
Stupacky. Spousta malych valecku, po 2.5mm
- posunute z roviny z=0 tal, aby pri preriznuti pro tisk v polovine
    byly 'nahore'
- posunute na stozaru nad patku
*/
zebrik_delkaStupne = 1;
zebrik_tloustka = 0.6   ;
zebrik_tloustkaR = zebrik_tloustka / 2;
module zebrik() {
    // posunout nad patku, a tesne nad rovinu z=0
    translate([0, -12, 0/* - 0.02 */])
    // sklopit do roviny
    rotate([0, 90, 0]) 
    for (x = [0 : -2.5 : -35]) {
        translate([0, x, 0]) rotate([0, 0, 30]) cylinder($fn=6, h=zebrik_delkaStupne + 0.1, r=zebrik_tloustkaR);
    }
}

module stozar_s_zebrikem() {
    union() {
        stozar();
        // ta 0.1 je zanoreni stupacky do valce stozaru
        translate([(1 - 0.1), 0, 0.00 ]) zebrik();
        translate([-(1 + 0.9), 0, 0.00 ]) zebrik();
    }
}

/*
4 uhelnik, vytazeny do prostoru. Posunuty po stozaru na 'sve misto'
*/
rameno_heightDiff = 0.3;

module rameno() {
    translate([0, -12 - 12*2.5 - 0.4, -0.7])
    linear_extrude(height = 1.4)
    polygon(points=[
        [0, 0], [0, -1.7], [4.6, -1.7 - rameno_heightDiff], [4.6, -1.7 - rameno_heightDiff + 1.2]
    ]);
}

module celyStozar() {
union() {
    stozar_s_zebrikem();
    translate([1 - 0.1, 0, 0]) rameno();
}
}


module stozarHorniPulka() {
    difference() {
        celyStozar();
        translate([-10, -60, -10]) cube([20, 60, 10]);
    }
}

module stozarDolniPulka() {
    rotate([0, 180, 0])
    difference() {
        celyStozar();
        translate([-10, -60, 0]) cube([20, 60, 10]);
    }
}

/// ============= SOKL pro navestidlo ===================
// Tato cast je ziskana z https://www.thingiverse.com/thing:4767402 by Zubozrout. Vse je vyrezano krome samotneho podstavce 
// a soklu. Vyska podstavce + soklu je 5mm, stejne jako podstavec ve vylisku LPH. Cely sokl je v mm podle (asi) typoveho vykresu
// nakonec se zmensi a posune do meritka TT (1:120), zmenseny je ale jen 1:100, aby vysel k ponekud tlustsimu stozaru
// (ten je zase tlustsi kvuli vedeni dratku)

wallThikness = 50;
singleBoxWidth = 600;
singleBoxHeight = 305;
singleBoxDiameter = 229;
coverHeight = 220;
singleBoxShadeLength = 500;
multipleBoxDiameter = 70;


module drawGroundBox(x, y, z, poleR = 100) {
    width = 250;
    height = 400;
    baseXMargin = -5;
    baseYMargin = 140;
    topXMargin = 20;
    topYMargin = 120;
    mainBoxStartZ = 120;
    decorationRadius = 25;
    baseHeight = 150;
    
    difference() {
        union() {
            translate([x, y - width, z + mainBoxStartZ + baseHeight])
                cube([width, width * 2, height - mainBoxStartZ], false);
            
            translate([x, y - width * 0.4, z + height + baseHeight])
                cube([width, width * 0.8, height / 10], false);
            
            translate([x, y - width * 0.35, z + baseHeight])
                cube([width, width * 0.7, mainBoxStartZ], false);
            
            translate([x + width * 0.5, y - width * 0.4, z + baseHeight + mainBoxStartZ * 0.7])
                rotate([45, 0, 0])
                    cube([width * 0.6, width * 0.5, mainBoxStartZ * 2], true);
            
            translate([x + width * 0.5, y + width * 0.4, z + baseHeight + mainBoxStartZ * 0.7])
                rotate([-45, 0, 0])
                    cube([width * 0.6, width * 0.5, mainBoxStartZ * 2], true);
            
            translate([x, y - width, z + mainBoxStartZ + baseHeight - 10])
                cube([width, 10, height - mainBoxStartZ + 20], false);
            
            translate([x, y + width, z + mainBoxStartZ + baseHeight - 10])
                cube([width, 10, height - mainBoxStartZ + 20], false);
            
            translate([x + width / 2 - width / 8, y + width - width / 10, z + mainBoxStartZ + height / 2.5 + baseHeight])
                linear_extrude(width / 4, scale = [1, 0.5])
                    square([width / 4, width / 5], false);
            
            translate([x + width / 2 + width / 8, y - width + width / 10, z + mainBoxStartZ + height / 2.5 + baseHeight])
                rotate([180, 180, 0])
                    linear_extrude(width / 4, scale = [1, 0.5])
                            square([width / 4, width / 5], false);
            
            translate([x - width * 0.25, y - width * 0.75, z + baseHeight])
                cube([width * 1.5, width * 1.5, 20], false);
            
            translate([x - decorationRadius, y + width * 0.7 - decorationRadius, z + baseHeight])
                cylinder(decorationRadius * 2, decorationRadius, decorationRadius, false);
                
            translate([x - decorationRadius, y - width * 0.7 + decorationRadius, z + baseHeight])
                cylinder(decorationRadius * 2, decorationRadius, decorationRadius, false);
                
            translate([x + width + decorationRadius, y + width * 0.7 - decorationRadius, z + baseHeight])
                cylinder(decorationRadius * 2, decorationRadius, decorationRadius, false);
            
            translate([x + width + decorationRadius, y - width * 0.7 + decorationRadius, z + baseHeight])
                cylinder(decorationRadius * 2, decorationRadius, decorationRadius, false);
            
            translate([x - width / 2, y - width, z])
                cube([width * 2, width * 2, baseHeight], false);
        }
        
        translate([x + width / 2, y, z - baseHeight / 2])
            cylinder(baseHeight + height * 2, poleR, poleR, false);
    }
}

module sokl() {
    scale([1/100, 1/100, 1/100])
    translate([-120, 0, 0])
    drawGroundBox(0, 0, 0);
}

/// ============= Konec: SOKL pro navestidlo ===================


soklRatio = 10/10;

difference() {

union() {
    translate([0, 8, 0]) difference() {
        celyStozar();
        translate([0.2, -43.5, 0]) rotate([50, 90, 0])   cylinder($fn=10, h = 10, r1 = 0.7, r2 = 0.7);
        translate([0.96, -44.68, 0]) rotate([3.8, 90, 0])   cylinder($fn=10, h = 10, r1 = 0.6, r2 = 0.6);
    }
    translate([0, 3, 0])
    rotate([90,90,0]) scale([soklRatio,soklRatio,soklRatio]) 
    sokl();
}
rotate([90, 0, 0])  cylinder(h=50, r=dutina_prumer / 2, $fn=50);
}